@@ -21,8 +21,22 @@ def user_save_patch(self, *args, **kwargs):
     self.username = self.email
 
 
-User.__init__ = user_init_patch
-User.save_base = user_save_patch
+original_init = User.__init__
+original_save_base = User.save_base
+
+
+def monkeypatch_user():
+    User.__init__ = user_init_patch
+    User.save_base = user_save_patch
+
+
+def unmonkeypatch_user():
+    User.__init__ = original_init
+    User.save_base = original_save_base
+
+
+monkeypatch_user()
+
 
 # Monkey-path the admin site to use a custom login form
 AdminSite.login_form = EmailAdminAuthenticationForm
